%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% PAcAlCI: Prediction of accuracies for 10 different methodologies according 
% to a set of sequences by means of a LS-SVM model. The most promising
% methodologies are also selected.
%
% Input:
%       - file: FASTA file with sequences to align.
%
% Output:
%       - accuracies: Predicted accuracies
%       - methods: Proposed alignment methods
%
% Francisco Ortuo 
% Department of Computer Architecture and Computer Technology
% University of Granada
% April 2014
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [accuracies, methods]=PAcAlCI(file);

% Read LS-SVM model
load model.mat;

% Methods 
used_methods = {'ClustalW2','Muscle','TCoffee','Kalign','Probcons','3DCoffee','Promals','MAFFT','FSA','RetAlign'};

% Retrieve the 10 most relevant features
features = extract_features(file);

% Predict from the model the accuracies
acc = simlssvm(model,features);
maxim=0.9999;acc(acc>=1)=maxim;
accuracies = struct('Method',used_methods,'Accuracy',num2cell(acc'));

% Select suitable methodologies
load mre.mat;
mre = mre_test; % Mean relative error
sigma_s = max(acc)*(1-mre);
methods = used_methods(acc>=sigma_s);


